//<

// $Id: fileutils.inc,v 1.3 2006/12/11 15:41:02 Jerome Loubersac Exp $
// $Revision: 1.3 $
// $Date: 2006/12/11 15:41:02 $

/*
  Implements a set of standard file functions
*/

/*
    Change history
    --------------
    When        Rev   Who   What
    2006-10-12  1.1   JBCL  First draft
    2006-11-06  1.2   JBCL  Added safelyDeleteFile function
    2006-12-11  1.3   AJJD  Adapted for unicode

*/

//  Public Members
//      bool fileExists(string sPath)
//      bool isEmptyFilename(string sPath)
//      void safelyDeleteFile(string sPath)
//      void safelyDeleteConfFile(string sPath)
//
//
//  Public Properties
//      none

//========================================================
// Function Name: fileExists
//
// Description: Returns true if the supplied path is
//              an existing directory.
//
// Type: Public
//
// Precondition: none
//
bool fileExists(string sPath)
{
    bool result = false

    Stat stat = create(sPath)
    if ( !null stat )
    {
        if (! directory(stat) )
        {
            result = true
        }

        delete(stat)
    }

    return result
}

//========================================================
// Function Name: isEmptyFilename
//
// Description: Returns true if the supplied path
//              is non empty, otherwise returns false
//
// Type: Public
//
// Precondition: none
//
bool isEmptyFilename(string sPath)
{
    bool result = false

    Regexp rEmpty = regexp "^[ \t]*$"

    if ( rEmpty sPath )
    {
        result = true
    }

    return result
}

//========================================================
// Function Name: safelyDeleteFile
//
// Description: If it exists then delete the specified file,
//              otherwise ignore.
//
// Type: Public
//
// Precondition: none
//
void safelyDeleteFile(string sPath)
{
    if (fileExists(sPath))
    {
        deleteFile(sPath)
    }
}

//========================================================
// Function Name: safelyDeleteConfFile
//
// Description: If it exists then delete the specified configuration file,
//              otherwise ignore.
//
// Type: Public
//
// Precondition: none
//
void safelyDeleteConfFile(string sPath, ConfType cType)
{
    if (confFileExists(sPath, cType))
    {
        confDeleteFile(sPath, cType)
    }
}


//
//========================================================
// Function Name: getAttributeType
//
// Description: convert doors attribute type to xsd attribute type
//
// Type: Public
//
// Precondition: none
//
string getAttributeType(string doors_type)
{
	if(doors_type=="Boolean")
	{
		return "boolean"
	}
	
	if(doors_type=="Date")
	{
		return "date"
	}
	
	if(doors_type=="Integer")
	{
		return "int"
	}
	
	if(doors_type=="Real")
	{
		return "float"
	}
	
	return "string"
}

string getDXLArgument()
{
	string filename = getenv("RPE_DXLARGUMENT")

	if( filename == null || filename == "")
	{
		string tempHome = getenv("TEMP") ""
		filename = tempHome "\\RPE\\rpe_doors.xml"
	}

	return filename
}
